@@ -40,7 +40,8 @@ setLocalTranslate('cl_install3',sys.modules[__name__])
 
 class DeviceHelper:
     sysBlockPath = '/sys/block'
-    rePassDevice = re.compile("^(?!%s)"%"|".join(['fd','ram','loop']))
+    rePassDevice = re.compile("^(?!%s)"%"|".join(['sr','fd',
+                                                  'ram','loop']))
 
     def getDeviceFromSysPath(self):
         """Get interest devices from sys block path"""
@@ -94,6 +95,7 @@ class VariableOsDeviceData(ReadonlyTableVariable):
               'os_device_table',
               'os_device_type',
               'os_device_ssd_set',
+              'os_device_virtual_set',
               'os_device_map',
               'os_device_name',
               'os_device_size']
@@ -125,7 +127,8 @@ class VariableOsDeviceDev(ReadonlyVariable,DeviceHelper):
         def _getDiskName(devpath):
             """Get devname only for by udevadm that devpath is device (disk)"""
             prop = getUdevDeviceInfo(devpath)
-            if prop.get("ID_TYPE","")=="disk" and \
+            if (prop.get("ID_TYPE","")=="disk" or 
+                path.exists(path.join(devpath,"device"))) and \
                    prop.get("DEVTYPE","")=="disk":
                 return prop.get('DEVNAME','')
 
@@ -223,6 +226,26 @@ class VariableOsDeviceSsdSet(ReadonlyVariable):
                    zip(self.Get('os_device_dev'),
                        self.Get('os_device_name')))
 
+class VariableOsDeviceVirtualSet(ReadonlyVariable):
+    """
+    Table on device
+    """
+    type = "list"
+    virtual_names = ("VBOX",)
+
+    def get(self):
+        """Get device partition table"""
+        def isVirtual(device, name):
+            if any(x in name for x in self.virtual_names):
+                return "on"
+            else:
+                return "off"
+
+        return map(lambda x: isVirtual(*x),
+                   zip(self.Get('os_device_dev'),
+                       self.Get('os_device_name')))
+
+
 class VariableOsDeviceTable(ReadonlyVariable):
     """
     Table on device
@@ -1420,7 +1443,6 @@ class VariableOsInstallDiskOptions(ReadonlyVariable):
     type = "list"
 
     def get(self):
-        """TODO: get real options"""
         def postProcess(opt):
             l_opt = filter(None,opt.split(','))
             return ",".join(l_opt)
@@ -1428,11 +1450,15 @@ class VariableOsInstallDiskOptions(ReadonlyVariable):
         diskOpts = dict(filter(lambda x:x[1],
                         zip(self.Get('os_disk_dev'),
                             self.Get('os_disk_options'))))
+        ssdDisk = dict(self.ZipVars('install.os_device_dev',
+                                    'install.os_device_ssd_set'))
         return map(postProcess,
                map(lambda x:diskOpts.get(x[0],x[1]),
-               map(lambda x:(x[0],FileSystemManager.getDefaultOpt(x[1])),
+               map(lambda x:(x[0],FileSystemManager.getDefaultOpt(x[1],
+                                  ssd=ssdDisk.get(x[2], 'off')=='on')),
                self.ZipVars('os_install_disk_dev',
-                            'os_install_disk_format'))))
+                            'os_install_disk_format',
+                            'os_install_disk_parent'))))
 
 class VariableOsInstallDiskFormat(ReadonlyVariable):
     """
